#!/usr/bin/python
#
# Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
#

# The ordering is important -- SolarisPackageDirBundle must come before
# DirectoryBundle, or the latter class will recognize a Solaris package
# as a plain directory.
__all__ = [
    "SolarisPackageDirBundle",
    "DirectoryBundle",
    "SolarisPackageDatastreamBundle",
    "TarBundle"
]

import os
import sys

class InvalidBundleException(Exception):
        def __unicode__(self):
                # To workaround python issues 6108 and 2517, this provides a
                # a standard wrapper for this class' exceptions so that they
                # have a chance of being stringified correctly.
                return str(self)


class Bundle(object):
        """Base bundle class."""

        def get_action(self, path):
                """Return the first action that matches the provided path or
                None."""
                for apath, data in self._walk_bundle():
                        if not apath:
                                continue
                        npath = apath.lstrip(os.path.sep)
                        if path == npath:
                                if type(data) == tuple:
                                        # Construct action on demand.
                                        return self.action(*data)
                                # Action was returned.
                                return data

def make_bundle(filename, targetpaths=()):
        """Determines what kind of bundle is at the given filename, and returns
        the appropriate bundle object.
        """

        for btype in __all__:
                bname = "pkg.bundle.%s" % btype
                bmodule = __import__(bname)

                bmodule = sys.modules[bname]
                if bmodule.test(filename):
                        bundle_create = getattr(bmodule, btype)
                        return bundle_create(filename, targetpaths=targetpaths)

        raise TypeError("Unknown bundle type for '%s'" % filename)


if __name__ == "__main__":
        try:
                b = make_bundle(sys.argv[1])
        except TypeError, e:
                print e
                sys.exit(1)

        for file in b:
                print file.type, file.attrs
                try:
                        print file.attrs["file"]
                        print os.stat(file.attrs["file"])
                except:
                        pass
